Merge commit 'remotes/yangtse/master'
[paraslash.git] / sched.c
diff --git a/sched.c b/sched.c
index a7660f5972c9f678b6f3a19b7b4398a1e43ae24b..ba43b10cff143960d3741fb6c0f7238b351de865 100644 (file)
--- a/sched.c
+++ b/sched.c
@@ -68,7 +68,7 @@ static void sched_post_select(struct sched *s)
  *
  * \sa task, now.
  */
-int sched(struct sched *s)
+int schedule(struct sched *s)
 {
        if (!initialized)
                return -E_NOT_INITIALIZED;
@@ -148,7 +148,7 @@ void unregister_task(struct task *t)
 /**
  * unregister all tasks
  *
* This will cause \a sched() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */
 void sched_shutdown(void)
@@ -148,7 +148,7 @@ void unregister_task(struct task *t)
  * unregister all tasks
  *
- * This will cause \a sched() to return immediately because both the
+ * This will cause \a schedule() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */